@@ -12,7 +12,20 @@ import traceback
 import unicodedata
 from collections import deque
 from os.path import basename
-from typing import TYPE_CHECKING, Any, AnyStr, Callable, Deque, Dict, List, Optional, Sequence, Set, Tuple, Union
+from typing import (  # noqa: F401
+    TYPE_CHECKING,
+    Any,
+    AnyStr,
+    Callable,
+    Deque,
+    Dict,
+    List,
+    Optional,
+    Sequence,
+    Set,
+    Tuple,
+    Union,
+)
 
 import yaml
 from six import PY2, binary_type, iteritems, raise_from, text_type
@@ -21,16 +34,17 @@ from ..config import is_affirmative
 from ..constants import ServiceCheck
 from ..errors import ConfigurationError
 from ..types import (
-    AgentConfigType,
-    Event,
-    ExternalTagType,
-    InitConfigType,
-    InstanceType,
-    ProxySettings,
-    ServiceCheckStatus,
+    AgentConfigType,  # noqa: F401
+    Event,  # noqa: F401
+    ExternalTagType,  # noqa: F401
+    InitConfigType,  # noqa: F401
+    InstanceType,  # noqa: F401
+    ProxySettings,  # noqa: F401
+    ServiceCheckStatus,  # noqa: F401
 )
 from ..utils.agent.utils import should_profile_memory
 from ..utils.common import ensure_bytes, to_native_string
+from ..utils.diagnose import Diagnosis
 from ..utils.http import RequestsWrapper
 from ..utils.limiter import Limiter
 from ..utils.metadata import MetadataManager
@@ -70,7 +84,7 @@ if not PY2:
     from pydantic import BaseModel, ValidationError
 
 if TYPE_CHECKING:
-    import ssl
+    import ssl  # noqa: F401
 
 # Metric types for which it's only useful to submit once per set of tags
 ONE_PER_CONTEXT_METRIC_TYPES = [aggregator.GAUGE, aggregator.RATE, aggregator.MONOTONIC_COUNT]
@@ -159,9 +173,14 @@ class AgentCheck(object):
     def __init__(self, *args, **kwargs):
         # type: (*Any, **Any) -> None
         """
-        - **name** (_str_) - the name of the check
-        - **init_config** (_dict_) - the `init_config` section of the configuration.
-        - **instance** (_List[dict]_) - a one-element list containing the instance options from the
+        Parameters:
+
+            name (str):
+                the name of the check
+            init_config (dict):
+                the `init_config` section of the configuration.
+            instance (list[dict]):
+                a one-element list containing the instance options from the
                 configuration file (a list is used to keep backward compatibility with
                 older versions of the Agent).
         """
@@ -375,6 +394,16 @@ class AgentCheck(object):
 
         return self._http
 
+    @property
+    def diagnosis(self):
+        # type: () -> Diagnosis
+        """
+        A Diagnosis object to register explicit diagnostics and record diagnoses.
+        """
+        if not hasattr(self, '_diagnosis'):
+            self._diagnosis = Diagnosis(sanitize=self.sanitize)
+        return self._diagnosis
+
     def get_tls_context(self, refresh=False, overrides=None):
         # type: (bool, Dict[AnyStr, Any]) -> ssl.SSLContext
         """
@@ -439,13 +468,13 @@ class AgentCheck(object):
         models_config = models_config or {}
         typos = set()  # type: Set[str]
 
-        known_options = set([k for k, _ in models_config])  # type: Set[str]
+        known_options = {k for k, _ in models_config}  # type: Set[str]
 
         if not PY2:
 
             if isinstance(models_config, BaseModel):
                 # Also add aliases, if any
-                known_options.update(set(models_config.dict(by_alias=True)))
+                known_options.update(set(models_config.model_dump(by_alias=True)))
 
         unknown_options = [option for option in user_configs.keys() if option not in known_options]  # type: List[str]
 
@@ -472,33 +501,29 @@ class AgentCheck(object):
             module_parts = self.__module__.split('.')
             package_path = '{}.config_models'.format('.'.join(module_parts[:2]))
         if self._config_model_shared is None:
-            raw_shared_config = self._get_config_model_initialization_data()
-            intg_shared_config = self._get_shared_config()
-            raw_shared_config.update(intg_shared_config)
-
-            shared_config = self.load_configuration_model(package_path, 'SharedConfig', raw_shared_config)
+            shared_config = copy.deepcopy(self.init_config)
+            context = self._get_config_model_context(shared_config)
+            shared_model = self.load_configuration_model(package_path, 'SharedConfig', shared_config, context)
             try:
-                self.log_typos_in_options(intg_shared_config, shared_config, 'init_config')
+                self.log_typos_in_options(shared_config, shared_model, 'init_config')
             except Exception as e:
                 self.log.debug("Failed to detect typos in `init_config` section: %s", e)
-            if shared_config is not None:
-                self._config_model_shared = shared_config
+            if shared_model is not None:
+                self._config_model_shared = shared_model
 
         if self._config_model_instance is None:
-            raw_instance_config = self._get_config_model_initialization_data()
-            intg_instance_config = self._get_instance_config()
-            raw_instance_config.update(intg_instance_config)
-
-            instance_config = self.load_configuration_model(package_path, 'InstanceConfig', raw_instance_config)
+            instance_config = copy.deepcopy(self.instance)
+            context = self._get_config_model_context(instance_config)
+            instance_model = self.load_configuration_model(package_path, 'InstanceConfig', instance_config, context)
             try:
-                self.log_typos_in_options(intg_instance_config, instance_config, 'instances')
+                self.log_typos_in_options(instance_config, instance_model, 'instances')
             except Exception as e:
                 self.log.debug("Failed to detect typos in `instances` section: %s", e)
-            if instance_config is not None:
-                self._config_model_instance = instance_config
+            if instance_model is not None:
+                self._config_model_instance = instance_model
 
     @staticmethod
-    def load_configuration_model(import_path, model_name, config):
+    def load_configuration_model(import_path, model_name, config, context):
         try:
             package = importlib.import_module(import_path)
         # TODO: remove the type ignore when we drop Python 2
@@ -512,7 +537,7 @@ class AgentCheck(object):
         model = getattr(package, model_name, None)
         if model is not None:
             try:
-                config_model = model(**config)
+                config_model = model.model_validate(config, context=context)
             # TODO: remove the type ignore when we drop Python 2
             except ValidationError as e:  # type: ignore
                 errors = e.errors()
@@ -537,17 +562,8 @@ class AgentCheck(object):
             else:
                 return config_model
 
-    def _get_shared_config(self):
-        # Any extra fields will be available during a config model's initial validation stage
-        return copy.deepcopy(self.init_config)
-
-    def _get_instance_config(self):
-        # Any extra fields will be available during a config model's initial validation stage
-        return copy.deepcopy(self.instance)
-
-    def _get_config_model_initialization_data(self):
-        # Allow for advanced functionality during the initial root validation stage
-        return {'__data': {'logger': self.log, 'warning': self.warning}}
+    def _get_config_model_context(self, config):
+        return {'logger': self.log, 'warning': self.warning, 'configured_fields': frozenset(config)}
 
     def register_secret(self, secret):
         # type: (str) -> None
@@ -635,6 +651,13 @@ class AgentCheck(object):
 
         aggregator.submit_event_platform_event(self, self.check_id, to_native_string(raw_event), "dbm-activity")
 
+    def database_monitoring_metadata(self, raw_event):
+        # type: (str) -> None
+        if raw_event is None:
+            return
+
+        aggregator.submit_event_platform_event(self, self.check_id, to_native_string(raw_event), "dbm-metadata")
+
     def should_send_metric(self, metric_name):
         return not self._metric_excluded(metric_name) and self._metric_included(metric_name)
 
@@ -694,15 +717,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Sample a gauge metric.
 
-        **Parameters:**
+        Parameters:
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._submit_metric(
             aggregator.GAUGE, name, value, tags=tags, hostname=hostname, device_name=device_name, raw=raw
@@ -712,13 +740,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Sample a raw count metric.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._submit_metric(
             aggregator.COUNT, name, value, tags=tags, hostname=hostname, device_name=device_name, raw=raw
@@ -730,14 +765,22 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool, bool) -> None
         """Sample an increasing counter metric.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
-        - **flush_first_value** (_bool_) - whether to sample the first value
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
+            flush_first_value (bool):
+                whether to sample the first value
         """
         self._submit_metric(
             aggregator.MONOTONIC_COUNT,
@@ -754,13 +797,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Sample a point, with the rate calculated at the end of the check.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._submit_metric(
             aggregator.RATE, name, value, tags=tags, hostname=hostname, device_name=device_name, raw=raw
@@ -770,13 +820,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Sample a histogram metric.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._submit_metric(
             aggregator.HISTOGRAM, name, value, tags=tags, hostname=hostname, device_name=device_name, raw=raw
@@ -786,13 +843,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Sample a histogram based on rate metrics.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._submit_metric(
             aggregator.HISTORATE, name, value, tags=tags, hostname=hostname, device_name=device_name, raw=raw
@@ -802,13 +866,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Increment a counter metric.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._log_deprecation('increment')
         self._submit_metric(
@@ -819,13 +890,20 @@ class AgentCheck(object):
         # type: (str, float, Sequence[str], str, str, bool) -> None
         """Decrement a counter metric.
 
-        - **name** (_str_) - the name of the metric
-        - **value** (_float_) - the value for the metric
-        - **tags** (_List[str]_) - a list of tags to associate with this metric
-        - **hostname** (_str_) - a hostname to associate with this metric. Defaults to the current host.
-        - **device_name** (_str_) - **deprecated** add a tag in the form `device:<device_name>` to the `tags`
-            list instead.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the metric
+            value (float):
+                the value for the metric
+            tags (list[str]):
+                a list of tags to associate with this metric
+            hostname (str):
+                a hostname to associate with this metric. Defaults to the current host.
+            device_name (str):
+                **deprecated** add a tag in the form `device:<device_name>` to the `tags` list instead.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         self._log_deprecation('increment')
         self._submit_metric(
@@ -836,11 +914,18 @@ class AgentCheck(object):
         # type: (str, ServiceCheckStatus, Sequence[str], str, str, bool) -> None
         """Send the status of a service.
 
-        - **name** (_str_) - the name of the service check
-        - **status** (_int_) - a constant describing the service status.
-        - **tags** (_List[str]_) - a list of tags to associate with this service check
-        - **message** (_str_) - additional information or a description of why this status occurred.
-        - **raw** (_bool_) - whether to ignore any defined namespace prefix
+        Parameters:
+
+            name (str):
+                the name of the service check
+            status (int):
+                a constant describing the service status
+            tags (list[str]):
+                a list of tags to associate with this service check
+            message (str):
+                additional information or a description of why this status occurred.
+            raw (bool):
+                whether to ignore any defined namespace prefix
         """
         tags = self._normalize_tags_type(tags or [])
         if hostname is None:
@@ -875,12 +960,17 @@ class AgentCheck(object):
 
     def set_metadata(self, name, value, **options):
         # type: (str, Any, **Any) -> None
-        """Updates the cached metadata ``name`` with ``value``, which is then sent by the Agent at regular intervals.
+        """Updates the cached metadata `name` with `value`, which is then sent by the Agent at regular intervals.
 
-        :param str name: the name of the metadata
-        :param object value: the value for the metadata. if ``name`` has no transformer defined then the
-                             raw ``value`` will be submitted and therefore it must be a ``str``
-        :param options: keyword arguments to pass to any defined transformer
+        Parameters:
+
+            name (str):
+                the name of the metadata
+            value (Any):
+                the value for the metadata. if ``name`` has no transformer defined then the
+                raw ``value`` will be submitted and therefore it must be a ``str``
+            options (Any):
+                keyword arguments to pass to any defined transformer
         """
         self.metadata_manager.submit(name, value, options)
 
@@ -924,7 +1014,10 @@ class AgentCheck(object):
         # type: (str) -> str
         """Returns the value previously stored with `write_persistent_cache` for the same `key`.
 
-        - **key** (_str_) - The key to retrieve
+        Parameters:
+
+            key (str):
+                the key to retrieve
         """
         return datadog_agent.read_persistent_cache(self._persistent_cache_id(key))
 
@@ -936,8 +1029,12 @@ class AgentCheck(object):
             - `/opt/datadog-agent/run` everywhere else.
         The cache is persistent between agent restarts but will be rebuilt if the check instance configuration changes.
 
-        - **key** (_str_) - Identifier used to build the filename
-        - **value** (_str_) - Value to store
+        Parameters:
+
+            key (str):
+                the key to retrieve
+            value (str):
+                the value to store
         """
         datadog_agent.write_persistent_cache(self._persistent_cache_id(key), value)
 
@@ -973,14 +1070,19 @@ class AgentCheck(object):
 
     def warning(self, warning_message, *args, **kwargs):
         # type: (str, *Any, **Any) -> None
-        """Log a warning message and display it in the Agent's status page.
+        """Log a warning message, display it in the Agent's status page and in-app.
 
         Using *args is intended to make warning work like log.warn/debug/info/etc
         and make it compliant with flake8 logging format linter.
 
-        :param str warning_message: the warning message.
-        :param list args: format string args used to format warning_message e.g. `warning_message % args`
-        :param dict kwargs: not used for now, but added to match Python logger's `warning` method signature
+        Parameters:
+
+            warning_message (str):
+                the warning message
+            args (Any):
+                format string args used to format the warning message e.g. `warning_message % args`
+            kwargs (Any):
+                not used for now, but added to match Python logger's `warning` method signature
         """
         warning_message = to_native_string(warning_message)
         # Interpolate message only if args is not empty. Same behavior as python logger:
@@ -1004,6 +1106,16 @@ class AgentCheck(object):
         self.warnings = []
         return warnings
 
+    def get_diagnoses(self):
+        # type: () -> str
+        """
+        Return the list of diagnosis as a JSON encoded string.
+
+        The agent calls this method to retrieve diagnostics from integrations. This method
+        runs explicit diagnostics if available.
+        """
+        return json.dumps([d._asdict() for d in (self.diagnosis.diagnoses + self.diagnosis.run_explicit())])
+
     def _get_requests_proxy(self):
         # type: () -> ProxySettings
         # TODO: Remove with Agent 5
@@ -1085,6 +1197,7 @@ class AgentCheck(object):
     def run(self):
         # type: () -> str
         try:
+            self.diagnosis.clear()
             # Ignore check initializations if running in a separate process
             if is_affirmative(self.instance.get('process_isolation', self.init_config.get('process_isolation', False))):
                 from ..utils.replay.execute import run_with_isolation
@@ -1105,19 +1218,8 @@ class AgentCheck(object):
                     from ..utils.agent.debug import enter_pdb
 
                     enter_pdb(self.check, line=self.init_config['set_breakpoint'], args=(instance,))
-                elif 'profile_memory' in self.init_config or (
-                    datadog_agent.tracemalloc_enabled() and should_profile_memory(datadog_agent, self.name)
-                ):
-                    from ..utils.agent.memory import profile_memory
-
-                    metrics = profile_memory(
-                        self.check, self.init_config, namespaces=self.check_id.split(':', 1), args=(instance,)
-                    )
-
-                    tags = self.get_debug_metric_tags()
-                    tags.extend(instance.get('__memory_profiling_tags', []))
-                    for m in metrics:
-                        self.gauge(m.name, m.value, tags=tags, raw=True)
+                elif self.should_profile_memory():
+                    self.profile_memory(self.check, self.init_config, args=(instance,))
                 else:
                     self.check(instance)
 
@@ -1164,7 +1266,10 @@ class AgentCheck(object):
         }
         ```
 
-        - **event** (_dict_) - the event to be sent
+        Parameters:
+
+            event (dict[str, Any]):
+                the event to be sent
         """
         # Enforce types of some fields, considerably facilitates handling in go bindings downstream
         for key, value in iteritems(event):
@@ -1245,3 +1350,31 @@ class AgentCheck(object):
         tags = ['check_name:{}'.format(self.name), 'check_version:{}'.format(self.check_version)]
         tags.extend(self.instance.get('tags', []))
         return tags
+
+    def get_memory_profile_tags(self):
+        # type: () -> List[str]
+        tags = self.get_debug_metric_tags()
+        tags.extend(self.instance.get('__memory_profiling_tags', []))
+        return tags
+
+    def should_profile_memory(self):
+        # type: () -> bool
+        return 'profile_memory' in self.init_config or (
+            datadog_agent.tracemalloc_enabled() and should_profile_memory(datadog_agent, self.name)
+        )
+
+    def profile_memory(self, func, namespaces=None, args=(), kwargs=None, extra_tags=None):
+        # type: (Callable[..., Any], Optional[Sequence[str]], Sequence[Any], Optional[Dict[str, Any]], Optional[List[str]]) -> None  # noqa: E501
+        from ..utils.agent.memory import profile_memory
+
+        if namespaces is None:
+            namespaces = self.check_id.split(':', 1)
+
+        tags = self.get_memory_profile_tags()
+        if extra_tags is not None:
+            tags.extend(extra_tags)
+
+        metrics = profile_memory(func, self.init_config, namespaces=namespaces, args=args, kwargs=kwargs)
+
+        for m in metrics:
+            self.gauge(m.name, m.value, tags=tags, raw=True)
