@@ -7,10 +7,11 @@ import re
 from copy import copy, deepcopy
 from itertools import chain
 from math import isinf, isnan
-from typing import List
+from typing import List  # noqa: F401
 
-from prometheus_client.openmetrics.parser import text_fd_to_metric_families as parse_metric_families_strict
-from prometheus_client.parser import text_fd_to_metric_families as parse_metric_families
+from prometheus_client.openmetrics.parser import text_fd_to_metric_families as parse_openmetrics
+from prometheus_client.parser import text_fd_to_metric_families as parse_prometheus
+from requests.exceptions import ConnectionError
 
 from ....config import is_affirmative
 from ....constants import ServiceCheck
@@ -81,6 +82,7 @@ class OpenMetricsScraper:
             raise ConfigurationError('Setting `raw_metric_prefix` must be a string')
 
         self.enable_health_service_check = is_affirmative(config.get('enable_health_service_check', True))
+        self.ignore_connection_errors = is_affirmative(config.get('ignore_connection_errors', False))
 
         self.hostname_label = config.get('hostname_label', '')
         if not isinstance(self.hostname_label, str):
@@ -167,7 +169,9 @@ class OpenMetricsScraper:
                             )
 
                     self.exclude_metrics_by_labels[label] = (
-                        lambda label_value, pattern=re.compile('|'.join(values)): pattern.search(label_value)
+                        lambda label_value, pattern=re.compile('|'.join(values)): pattern.search(  # noqa: B008
+                            label_value
+                        )  # noqa: B008, E501
                         is not None
                     )
                 else:
@@ -215,13 +219,11 @@ class OpenMetricsScraper:
 
         self.http = RequestsWrapper(config, self.check.init_config, self.check.HTTP_CONFIG_REMAPPER, self.check.log)
 
-        # Decide how strictly we will adhere to the latest version of the specification
-        if is_affirmative(config.get('use_latest_spec', False)):
-            self.parse_metric_families = parse_metric_families_strict
-            # https://github.com/prometheus/client_python/blob/v0.9.0/prometheus_client/openmetrics/exposition.py#L7
-            accept_header = 'application/openmetrics-text; version=0.0.1; charset=utf-8'
+        self._content_type = ''
+        self._use_latest_spec = is_affirmative(config.get('use_latest_spec', False))
+        if self._use_latest_spec:
+            accept_header = 'application/openmetrics-text;version=1.0.0,application/openmetrics-text;version=0.0.1'
         else:
-            self.parse_metric_families = parse_metric_families
             accept_header = 'text/plain'
 
         # Request the appropriate exposition format
@@ -277,6 +279,15 @@ class OpenMetricsScraper:
         if self.raw_line_filter is not None:
             line_streamer = self.filter_connection_lines(line_streamer)
 
+        # Since we determine `self.parse_metric_families` dynamically from the response and that's done as a
+        # side effect inside the `line_streamer` generator, we need to consume the first line in order to
+        # trigger that side effect.
+        try:
+            line_streamer = chain([next(line_streamer)], line_streamer)
+        except StopIteration:
+            # If line_streamer is an empty iterator, next(line_streamer) fails.
+            return
+
         for metric in self.parse_metric_families(line_streamer):
             self.submit_telemetry_number_of_total_metric_samples(metric)
 
@@ -287,6 +298,19 @@ class OpenMetricsScraper:
 
             yield metric
 
+    @property
+    def parse_metric_families(self):
+        media_type = self._content_type.split(';')[0]
+        # Setting `use_latest_spec` forces the use of the OpenMetrics format, otherwise
+        # the format will be chosen based on the media type specified in the response's content-header.
+        # The selection is based on what Prometheus does:
+        # https://github.com/prometheus/prometheus/blob/v2.43.0/model/textparse/interface.go#L83-L90
+        return (
+            parse_openmetrics
+            if self._use_latest_spec or media_type == 'application/openmetrics-text'
+            else parse_prometheus
+        )
+
     def generate_sample_data(self, metric):
         """
         Yield a sample of processed data.
@@ -338,9 +362,17 @@ class OpenMetricsScraper:
         Yield the connection line.
         """
 
-        with self.get_connection() as connection:
-            for line in connection.iter_lines(decode_unicode=True):
-                yield line
+        try:
+            with self.get_connection() as connection:
+                # Media type will be used to select parser dynamically
+                self._content_type = connection.headers.get('Content-Type', '')
+                for line in connection.iter_lines(decode_unicode=True):
+                    yield line
+        except ConnectionError as e:
+            if self.ignore_connection_errors:
+                self.log.warning("OpenMetrics endpoint %s is not accessible", self.endpoint)
+            else:
+                raise e
 
     def filter_connection_lines(self, line_streamer):
         """
@@ -378,6 +410,7 @@ class OpenMetricsScraper:
                     response.encoding = 'utf-8'
 
                 self.submit_telemetry_endpoint_response_size(response)
+
                 return response
 
     def send_request(self, **kwargs):
@@ -443,6 +476,7 @@ class OpenMetricsCompatibilityScraper(OpenMetricsScraper):
     def __init__(self, check, config):
         new_config = deepcopy(config)
         new_config.setdefault('enable_health_service_check', new_config.pop('health_service_check', True))
+        new_config.setdefault('ignore_connection_errors', new_config.pop('ignore_connection_errors', False))
         new_config.setdefault('collect_histogram_buckets', new_config.pop('send_histograms_buckets', True))
         new_config.setdefault('non_cumulative_histogram_buckets', new_config.pop('non_cumulative_buckets', False))
         new_config.setdefault('histogram_buckets_as_distributions', new_config.pop('send_distribution_buckets', False))
