@@ -5,16 +5,14 @@
 # Licensed under a 3-clause BSD style license (see LICENSE)
 import json
 import logging
-from typing import Any
+from typing import Any  # noqa: F401
 
 import mock
 import pytest
 from six import PY3
 
-from datadog_checks.base import AgentCheck
+from datadog_checks.base import AgentCheck, to_native_string
 from datadog_checks.base import __version__ as base_package_version
-from datadog_checks.base import to_native_string
-from datadog_checks.base.checks.base import datadog_agent
 from datadog_checks.dev.testing import requires_py3
 
 
@@ -624,15 +622,17 @@ class TestTags:
             check.set_external_tags(external_host_tags)
             assert external_host_tags == [('hostname', {'src_name': ['normalize:tag']})]
 
-    def test_external_hostname(self):
+    def test_external_hostname(self, datadog_agent):
         check = AgentCheck()
         external_host_tags = [(u'hostnam\xe9', {'src_name': ['key1:val1']})]
-        with mock.patch.object(datadog_agent, 'set_external_tags') as set_external_tags:
-            check.set_external_tags(external_host_tags)
-            if PY3:
-                set_external_tags.assert_called_with([(u'hostnam\xe9', {'src_name': ['key1:val1']})])
-            else:
-                set_external_tags.assert_called_with([('hostnam\xc3\xa9', {'src_name': ['key1:val1']})])
+        check.set_external_tags(external_host_tags)
+
+        if PY3:
+            datadog_agent.assert_external_tags(u'hostnam\xe9', {'src_name': ['key1:val1']})
+        else:
+            datadog_agent.assert_external_tags('hostnam\xc3\xa9', {'src_name': ['key1:val1']})
+
+        datadog_agent.assert_external_tags_count(1)
 
     @pytest.mark.parametrize(
         "disable_generic_tags, expected_tags",
@@ -977,20 +977,19 @@ def test_load_configuration_models(dd_run_check, mocker):
     instance_config = {}
     shared_config = {}
     package = mocker.MagicMock()
-    package.InstanceConfig = mocker.MagicMock(return_value=instance_config)
-    package.SharedConfig = mocker.MagicMock(return_value=shared_config)
+    package.InstanceConfig.model_validate = mocker.MagicMock(return_value=instance_config)
+    package.SharedConfig.model_validate = mocker.MagicMock(return_value=shared_config)
     import_module = mocker.patch('importlib.import_module', return_value=package)
 
     dd_run_check(check)
 
-    instance_data = check._get_config_model_initialization_data()
-    instance_data.update(instance)
-    init_config_data = check._get_config_model_initialization_data()
-    init_config_data.update(init_config)
-
     import_module.assert_called_with('datadog_checks.base.config_models')
-    package.InstanceConfig.assert_called_once_with(**instance_data)
-    package.SharedConfig.assert_called_once_with(**init_config_data)
+    package.InstanceConfig.model_validate.assert_called_once_with(
+        instance, context=check._get_config_model_context(instance)
+    )
+    package.SharedConfig.model_validate.assert_called_once_with(
+        init_config, context=check._get_config_model_context(init_config)
+    )
 
     assert check._config_model_instance is instance_config
     assert check._config_model_shared is shared_config
@@ -998,11 +997,7 @@ def test_load_configuration_models(dd_run_check, mocker):
 
 if PY3:
 
-    from pydantic import BaseModel, Field
-
-    class BaseModelTest(BaseModel):
-        field = ""
-        schema_ = Field("", alias='schema')
+    from .utils import BaseModelTest
 
 else:
 
