@@ -6,13 +6,13 @@ from datadog_checks.dev.testing import requires_py3
 pytestmark = [requires_py3]
 
 
-def test_make_immutable_check_config():
+def test_make_immutable():
     # TODO: move imports up top when we drop Python 2
-    from immutables import Map
+    from types import MappingProxyType
 
-    from datadog_checks.base.utils.models.types import make_immutable_check_config
+    from datadog_checks.base.utils.models.validation.utils import make_immutable
 
-    obj = make_immutable_check_config(
+    obj = make_immutable(
         {
             'string': 'foo',
             'integer': 9000,
@@ -23,7 +23,7 @@ def test_make_immutable_check_config():
         }
     )
 
-    assert isinstance(obj, Map)
+    assert isinstance(obj, MappingProxyType)
     assert len(obj) == 6
     assert isinstance(obj['string'], str)
     assert obj['string'] == 'foo'
@@ -35,10 +35,10 @@ def test_make_immutable_check_config():
     assert obj['boolean'] is True
     assert isinstance(obj['array'], tuple)
     assert len(obj['array']) == 2
-    assert isinstance(obj['array'][0], Map)
+    assert isinstance(obj['array'][0], MappingProxyType)
     assert obj['array'][0]['key'] == 'foo'
-    assert isinstance(obj['array'][1], Map)
+    assert isinstance(obj['array'][1], MappingProxyType)
     assert obj['array'][1]['key'] == 'bar'
-    assert isinstance(obj['mapping'], Map)
+    assert isinstance(obj['mapping'], MappingProxyType)
     assert len(obj['mapping']) == 1
     assert obj['mapping']['foo'] == 'bar'
